.. _generators:


Graph generators
****************

.. currentmodule:: networkx

Atlas
-----
.. automodule:: networkx.generators.atlas
.. autosummary::
   :toctree: generated/

   graph_atlas_g

Classic
-------
.. automodule:: networkx.generators.classic
.. autosummary::
   :toctree: generated/
   
   balanced_tree
   barbell_graph
   complete_graph
   complete_bipartite_graph
   circular_ladder_graph
   cycle_graph
   dorogovtsev_goltsev_mendes_graph
   empty_graph
   grid_2d_graph
   grid_graph
   hypercube_graph
   ladder_graph
   lollipop_graph
   null_graph
   path_graph
   star_graph
   trivial_graph
   wheel_graph

Small
-----
.. automodule:: networkx.generators.small
.. autosummary::
   :toctree: generated/

   make_small_graph
   LCF_graph
   bull_graph
   chvatal_graph
   cubical_graph
   desargues_graph
   diamond_graph
   dodecahedral_graph
   frucht_graph
   heawood_graph
   house_graph
   house_x_graph
   icosahedral_graph
   krackhardt_kite_graph
   moebius_kantor_graph
   octahedral_graph
   pappus_graph
   petersen_graph
   sedgewick_maze_graph
   tetrahedral_graph
   truncated_cube_graph
   truncated_tetrahedron_graph
   tutte_graph


Random Graphs
-------------
.. automodule:: networkx.generators.random_graphs
.. autosummary::
   :toctree: generated/

   fast_gnp_random_graph
   gnp_random_graph
   dense_gnm_random_graph
   gnm_random_graph
   erdos_renyi_graph
   binomial_graph
   newman_watts_strogatz_graph
   watts_strogatz_graph
   connected_watts_strogatz_graph
   random_regular_graph
   barabasi_albert_graph
   powerlaw_cluster_graph
   random_lobster
   random_shell_graph
   random_powerlaw_tree
   random_powerlaw_tree_sequence


Degree Sequence
---------------
.. automodule:: networkx.generators.degree_seq

.. autosummary::
   :toctree: generated/

   configuration_model
   directed_configuration_model
   expected_degree_graph
   havel_hakimi_graph
   degree_sequence_tree
   random_degree_sequence_graph

Random Clustered
----------------
.. automodule:: networkx.generators.random_clustered

.. autosummary::
   :toctree: generated/

   random_clustered_graph

SMax
----
.. automodule:: networkx.generators.smax

.. autosummary::
   :toctree: generated/

   li_smax_graph


Directed
--------
.. automodule:: networkx.generators.directed
.. autosummary::
   :toctree: generated/

   gn_graph
   gnr_graph
   gnc_graph
   scale_free_graph


Geometric
---------
.. automodule:: networkx.generators.geometric
.. autosummary::
   :toctree: generated/

   random_geometric_graph
   geographical_threshold_graph
   waxman_graph
   navigable_small_world_graph


Hybrid
------
.. automodule:: networkx.generators.hybrid
.. autosummary::
   :toctree: generated/

   kl_connected_subgraph
   is_kl_connected


Bipartite
---------
.. automodule:: networkx.generators.bipartite
.. autosummary::
   :toctree: generated/

   bipartite_configuration_model
   bipartite_havel_hakimi_graph
   bipartite_reverse_havel_hakimi_graph
   bipartite_alternating_havel_hakimi_graph
   bipartite_preferential_attachment_graph
   bipartite_random_regular_graph
   bipartite_random_graph
   bipartite_gnmk_random_graph


Line Graph
----------
.. automodule:: networkx.generators.line
.. autosummary::
   :toctree: generated/

   line_graph


Ego Graph
---------
.. automodule:: networkx.generators.ego
.. autosummary::
   :toctree: generated/

   ego_graph

Stochastic
----------
.. automodule:: networkx.generators.stochastic
.. autosummary::
   :toctree: generated/

   stochastic_graph

Intersection
------------
.. automodule:: networkx.generators.intersection
.. autosummary::
   :toctree: generated/

   uniform_random_intersection_graph
   k_random_intersection_graph
   general_random_intersection_graph

Social Networks
---------------
.. automodule:: networkx.generators.social
.. autosummary::
   :toctree: generated/

   karate_club_graph
   davis_southern_women_graph
   florentine_families_graph

